@@ -345,8 +345,8 @@ class UserGroups(Collection):
             List of permissions, `['create', 'read', 'delete', 'write']`
     """
     collection_name = 'users_groups'
-    userID = ReferenceField('pfunk.contrib.auth.collections.User')
-    groupID = ReferenceField(Group)
+    userID = ReferenceField(env('USER_COLLECTION', 'pfunk.contrib.auth.collections.User'))
+    groupID = ReferenceField(env('GROUP_COLLECTION', 'pfunk.contrib.auth.collections.Group'))
     permissions = ListField()
 
     def __unicode__(self):
